
# Slot: dtype




URI: [nwb_schema_language:CompoundDtype_dtype](https://w3id.org/p2p_ld/nwb-schema-language/CompoundDtype_dtype)


## Domain and Range

[CompoundDtype](CompoundDtype.md) &#8594;  <sub>1..\*</sub> [String](types/String.md)

## Parents

 *  is_a: [dtype](dtype.md)

## Children


## Used by

 * [CompoundDtype](CompoundDtype.md)
